<?php
/**
* © Copyright 2007 IntraHealth International, Inc.
* 
* This File is part of I2CE 
* 
* I2CE is free software; you can redistribute it and/or modify 
* it under the terms of the GNU General Public License as published by 
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful, 
* but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License 
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
*  iHRIS_PageFormLists
* @package I2CE
* @subpackage Core
* @author Carl Leitner <litlfred@ibiblio.org>
* @copyright Copyright &copy; 2007 IntraHealth International, Inc. 
* This file is part of I2CE. I2CE is free software; you can redistribute it and/or modify it under 
* the terms of the GNU General Public License as published by the Free Software Foundation; either 
* version 3 of the License, or (at your option) any later version. I2CE is distributed in the hope 
* that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have 
* received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
* @version 2.1
* @access public
*/


class iHRIS_PageFormLists extends I2CE_PageFormLists{

    /**
     * Load the HTML template files for editing and confirming the list information.
     * 
     * Since this page has special versions, this method is only called when a particular list object
     * is being added or edited.  All other pages are loaded within the {@link action} method.
     */
    protected function loadHTMLTemplates() {
        parent::loadHTMLTemplates();
        if ( $this->showContact() ) {
            $this->template->appendFileById( "lists_form_contact.html", "tbody", "list_fields" );
        }
    }

    /**
     * Create and load data for the objects used for this form.
     * 
     * Create the list object and if this is a form submission load
     * the data from the form data.  It determines the type based on the
     * {@link $type} member variable.
     */
    protected function loadObjects() {
        if ( $this->showContact() ) {
            $factory = I2CE_FormFactory::instance();
            $contact = $factory->createForm( "contact" );
            $contact->contact_type = $factory->getConst( "contact", $this->getContactType() );
            $this->setObject( $contact, I2CE_PageForm::EDIT_CHILD );
        }
        parent::loadObjects();
    }


    /**
     * Check to see if the current type should display contact information when editing this list object.
     * @return boolean
     */
    public function showContact() {
        if( is_scalar($this->type) && $this->type  && is_array($this->args['lists_with_contact'])) {
            return in_array($this->type,$this->args['lists_with_contact']);
        } else {
            return false;
        }
    }

    
    protected function getContactType() {
        if( is_scalar($this->type) 
            && $this->type  
            && is_array($this->args['contact_types'])
            && in_array($this->type,$this->args['contact_types'])) {
            return $this->args['contact_types'][$this->type];
        } else {        
            return "TYPE_FACILITY";
        }
    }


    /**
     * Check if this type has a special page to display for the edit selection lists.
     * 
     * This will be needed if the object is linked to another form so the drop downs can be displayed.
     * Optionally this method will return the object to use to populate the drop downs.
     * @param string $type
     * @param boolean $return_object
     * @return mixed Boolean or the I2CE_List object to populate the drop downs.
     */
    public function getExtra( $type, $return_object=false ) {
        if ( $type == "region" || $type == "district" || $type == "county" ) {
            if ( $return_object ) {
                return new iHRIS_LocationSelect( $type );
            } else {
                return true;           
            }
        } else {
            return false;
        }
    }

    /**
     * Set the attributes for the left hand navigation menu to highlight the proper location.
     */
    protected function setMenus() {
        $this->template->setAttribute( "class", "active", "menuConfigure", "a[@href='configure']" );
        $this->template->appendFileById( "menu_configure.html", "ul", "menuConfigure" );
        $this->template->setAttribute( "class", "active", "menuLists", "a[@href='lists']" );
    }

}
# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
