<?php
/**
* © Copyright 2007 IntraHealth International, Inc.
* 
* This File is part of I2CE 
* 
* I2CE is free software; you can redistribute it and/or modify 
* it under the terms of the GNU General Public License as published by 
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful, 
* but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License 
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
*  iHRIS_PageViewList
* @package I2CE
* @subpackage Core
* @author Carl Leitner <litlfred@ibiblio.org>
* @copyright Copyright &copy; 2007 IntraHealth International, Inc. 
* This file is part of I2CE. I2CE is free software; you can redistribute it and/or modify it under 
* the terms of the GNU General Public License as published by the Free Software Foundation; either 
* version 3 of the License, or (at your option) any later version. I2CE is distributed in the hope 
* that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have 
* received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
* @version 2.1
* @access public
*/


class iHRIS_PageViewList extends I2CE_PageViewList {

    /**
     * Perform the actions of the page.
     * 
     * This handles some special actions because there are three versions of this page:
     * - The list page of all objects that can be edited.
     * - The add/update page for each list object.
     * - The edit form for each list object.
     * 
     * Only in the third case is the parent object action method called since that is the default setup
     * for editing objects used in most other {@link PageForm} objects.
     */
    protected function action() {
        parent::action();
        $this->template->setAttribute( "class", "active", "menuConfigure", "a[@href='configure']" );
        $this->template->appendFileById( "menu_configure.html", "ul", "menuConfigure" );
        $this->template->setAttribute( "class", "active", "menuLists", "a[@href='lists']" );
        if (!is_array($this->args['types'])) {
            return;
        }
        if (!array_key_exists($this->type,$this->args['types'])) {
            return;
        }
        $data= $this->args['types'][$this->type];
        $child_forms = array();
        if ($data['has_contact']) {
            $child_forms[] = 'contact';
        }
        if (!is_array($data['child_lists'])) {
            $data['child_lists'] = array();
        }
        $child_forms = array_unique(array_merge($child_forms,$data['child_lists']));
        $this->list->populateChildren( $child_forms );
        if ( $data['has_contact'] 
             && array_key_exists( "contact", $this->list->children ) 
             && count( $this->list->children['contact'] )> 0 
            ) {            
            $this->template->setForm( $this->list->children['contact'][0] );            
        }
        

        foreach ($data['child_lists'] as $form) {            
            if (!array_key_exists($form, $this->list->children) || !is_array($this->list->children[$form]))  {
                continue;
            }
            foreach( $this->list->children[$form] as $obj ) {
                $node = $this->template->appendFileById( "view_list_" . $form . ".html", "div", $form );
                $this->template->setForm( $obj, $node );
            }
        }

    }


}
# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
