<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *//**
    * @package I2CE
    * @author Luke Duncan <lduncan@intrahealth.org>
    * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
    * @since v2.0.0
    * @version v2.0.0
    */
/**
 * Class for defining all the database fields used by a {@link I2CE_Form} object.
 * @package I2CE
 * @access public
 */
class iHRIS_FormField_CURRENCY extends I2CE_FormField_DB_STRING { 

    /**
     * Return the value of this field from the database format for the given type
     * @param integer $type The type of the field to be returned.
     * @param mixed $value
     */
    public function getFromDB($value ) {
        return explode( "|", $value);
    }

        
                
    /**  
     * Sets the value of this field from the posted form.
     * @param array &$post The $_POST array holding the values for this form.
     */
    public function setFromPost( &$post ) {
        $value = array();
        $post_name = $this->getHTMLName();
        if ( array_key_exists( $post_name . "_currency", $post ) ) {
            if ( array_key_exists( $post_name, $post ) ) {
                $value[0] = $post[$post_name . "_currency"];
                $value[1] = $post[$post_name];
            }
        } elseif ( array_key_exists( $post_name, $post ) ) {
            $value = explode( "|", $post[$post_name] );
            if ( count( $value ) == 1 ) {
                $value = array( "", $value[0] );
            }
        }
        $this->value = $value;
    }
        
        

    public function getValue() {
        if (!$this->isSetValue()) {
            return array();
        }
        return $this->value;
    }

    public function getDBValue() {
        return implode( "|", $this->getValue() );
    }
        
    /**
     * Returns the value of this field as a human readable format.
     * @param I2CE_Entry $entry If a I2CE_Entry object has been passed to this method then it will return the value for that entry assuming it's an 
     * entry for this field.
     * @param boolean $number_format If true, call number_format on the returned value.
     * @return mixed
     */
    public function getDisplayValue( $entry=false, $number_format=false ) {
        if ( $entry instanceof I2CE_Entry ) {
            $value = $entry->getValue();
        } else {
            $value = $this->getValue();
        }
        $number_value = $value[1];
        if ( $number_format ) $number_value = number_format( $number_value );
        if ( $this->isMap() )
            return $this->mapLookup( $value[0] ) . $number_value;
        else
            return $number_value;
        break;
    }

    /**
     * Multiply the value of this field by the given value.
     */
    public function multiply( $value ) {
        if ( $value instanceof iHRIS_FormField_CURRENCY ) {
            $add_value = $value->getValue();
            $add_number = $add_value[1];
        } else {
            $add_number = $value;
        }
        $this->value[1] = round( $this->value[1] * $add_number );
    }
    /**
     * Add the given value to the value of this field.
     */
    public function add( $value ) {
        if ( $value instanceof iHRIS_FormField_CURRENCY ) {
            $add_value = $value->getValue();
            $add_number = $add_value[1];
        } else {
            $add_number = $value;
        }
        $this->value[1] += $add_number;
    }

    /**
     * Checks to see if the current value for this is set and valid.
     * @return boolean
     */
  
    public function isValid() {
        $value = $this->getValue();
        return I2CE_Validate::checkCurrency( $value[1] );
    }
        




    protected function processDOMEditable($node,$template,$showError,$form_node) {
        $node_list = array();
        $ele_name = $this->getHTMLName();
        $value = $this->getValue();
        if ( $this->isMap() ) {
            $currency = $template->createElement( "select", array( "name" => $ele_name . "_currency", "class" => "currency" ) );
            $optionList = $template->getData('OPTION','',$ele_name,true,false);
            $optionList = $template->getData('OPTION',$this->getHTMLName(false),$node,true,false);
            $template->removeData('OPTION',$this->getHTMLName(false));
            if (!is_array($optionList)) {
                $optionList = array();
            }
            $opt_blank = $template->createElement( "option", array( "value" => "", "class" => "blank_opt" ), "Select" );
            $currency->appendChild( $opt_blank );
            foreach( $optionList as $option) {
                $opt_id = $option['value'];
                $opt_value = $option['text'];
                $opt = $template->createElement( "option", array( "value" => $opt_id ), $opt_value );
                if ( $value[0] == $opt_id ) {
                    $opt->setAttribute( "selected", "selected" );
                }
                $currency->appendChild( $opt );
            }
            $node_list[]=$currency ;
                        
        }
        $element = $template->createElement( "input", array( "name" => $ele_name, "id" => $ele_name, "type" => "text", "value" => $value[1], "class" => "currency" ) );
        $this->setElement($element);
        $node_list[]= $element ;
        return $node_list;
                
    }

                




}

# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
