<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @package iHRIS
 * @subpackage Common
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v2.0.0
 * @version v2.0.0
 */
/**
 * Object for dealing with selecting locations for a drop down.
 * 
 * This object is based on the normal location but only includes the necessary fields so that
 * the location select page can limit choices based on the current location.
 * @package iHRIS
 * @subpackage Common
 * @access public
 */
class iHRIS_LocationSelect extends I2CE_List {

    public function usesLastEntry() {
        return false;
    }

    /**
     * Create a new instance of a location selector.
     * 
     * @param string $type The form type to be used.
     */
    public function __construct( $type ) {
        parent::__construct( $type, 0 );
        $this->setDisplayName( "Location" );
            
        $this->addField('country', array( 'formfield' => 'INT', 'required' =>  true ) );
        $this->fields['country']->setMap( "country", "lookup", "listLocation" );
        
        if ( $type == "region" ) {
            $this->addField( 'id', array( 'formfield' => 'INT', 'in_db' => false ) );
            $this->fields['id']->setMap( "region" );
            $this->fields['id']->setLink( $this->fields['country'] );
        } else {
            $this->addField('region', array( 'formfield' => 'INT', 'required' => true ) );
            $this->fields['region']->setMap();
            $this->fields['region']->setLink( $this->fields['country'] );
                
            if ( $type == "district" ) {
                $this->addField( 'id', array( 'formfield' => 'INT', 'in_db' => false ) );
                $this->fields['id']->setMap( "district" );
                $this->fields['id']->setLink( $this->fields['region'] );
            } else {
                $this->addField( 'district', array( 'formfield' => 'INT', 'required' => true ) );
                $this->fields['district']->setMap();
                $this->fields['district']->setLink( $this->fields['region'] );
                        
                if ( $type == "county" ) {
                    $this->addField( 'id', array( 'formfield' => 'INT', 'in_db' => false ) );
                    $this->fields['id']->setMap( "county" );
                    $this->fields['id']->setLink( $this->fields['district'] );                                  
                }
            }
        }
    }
    
}

# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
