<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @package iHRIS
 * @subpackage Manage
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v1.0.0
 * @version v2.0.0
 */
/**
 * Object for dealing with competencies.
 * 
 * @package iHRIS
 * @subpackage Manage
 * @access public
 */
class iHRIS_Competency extends I2CE_List {

    /**
     * Return the list edit type for this list.
     * 
     * The possible return values are "list," "dual," or "select." Select will display a drop down of 
     * all choices and list and dual will list them all in a table.  Dual includes the linked list object for the
     * object.
     * @return string
     */
    public function getListType() { return "dual"; }

    /**
     * Create a new instance of a competency.
     * 
     * @param string $form The name of this form
     * @param integer $id
     */
    public function __construct( $form, $id = 0 ) {
        parent::__construct( $form, $id );
        $this->fields['type']->setValue( $form );
    }

    /**
     * List all competencies by type (the linked form for this object).
     * 
     * This will return an array that includes all competency types with all competencies
     * that are in that type.
     * @return array
     */
    static public function getOptionsByLink() {
        $factory = I2CE_FormFactory::instance();
        return parent::_getOptionsByLink( $factory->getFormName( get_class() ), self::MAIN_FIELD, "competency_type" );
    }



    static public function getCompetencyWithType($id) {
        if ($id > 0) {
            return self::getCompetenciesByType(true,$id);
        } else {
            return '';
        }
    }

    /**
     * List all competencies by type (the linked form for this object).
     * 
     * This will return an array that includes all competency types with all competencies
     * that are in that type.
     * @return array
     */
    static public function getCompetenciesByType($flat = true, $id = null) {
        $options =array();
        $values = array();
        foreach (array(array('competency','name'),array('competency','competency_type'),array('competency_type','name')) as $formfield) {
            list($form,$field) = $formfield;
            $data = I2CE_FormField::getFormFieldIdAndType($form,$field);
            if (!is_array($data)) {
                I2CE::raiseError("Could not available competencies b/c could not find field $field in form $form");
                return array();
            }
            $values[] = $data['id'];
        }
        $query = "SELECT le_comp.record AS id, le_comp.string_value AS competency, le_comp_type.string_value AS type ";
        $query.= "FROM last_entry le_comp ";
        $query.= "JOIN last_entry le_comp2  ON le_comp.record = le_comp2.record ";
        $query.= "JOIN last_entry le_comp_type ON le_comp2.integer_value = le_comp_type.record ";
        $query.= "WHERE le_comp.form_field = ? ";  //competency:name
        $query.= "AND le_comp2.form_field = ? "; //competency:competency_type
        $query.= "AND le_comp_type.form_field = ? "; //competency_type:name
        if ($id > 0) {
            $query .= "AND le_comp.record = ? ";
            $values[] = $id;
        }
        $query .= "ORDER BY type, competency";
        $db = MDB2::singleton();
        $sth = $db->prepare($query,array('integer','integer','integer'), MDB2_PREPARE_RESULT );
        if (I2CE::pearError($sth,"Could not setup statement to get available courses")) {
            return array();
        }
        $results = $sth->execute($values);
        if (I2CE::pearError($results,"Could not get competencies:$query\n" . print_r($values,true))) {
            return array();
        }
        
        while ( $result =& $results->fetchRow() ) {
            if ($flat) {
                $options[$result->id] = $result->type . " - " . $result->competency;
            } else {
                $options[$result->type][$result->id] = $result->competency;
            }
        }
        if ($id > 0) {
            if (array_key_exists($id,$options)) {
                return $options[$id];
            } else {
                return '';
            }
        } else {
            return $options;
        }
    }

}

# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
