<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @package iHRIS
 * @subpackage Manage
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v1.0.0
 * @version v2.0.0
 */
/**
 * Object for dealing with classifications.
 * 
 * @package iHRIS
 * @subpackage Manage
 * @access public
 */
class iHRIS_Training_Course extends I2CE_List {
    



    /**
     * Create a new instance of a classification.
     * 
     * @param string $form The name of this form
     * @param integer $id
     */
    public function __construct( $form, $id = 0 ) {
        parent::__construct( $form, $id );
        $this->fields['type']->setValue( $form );                
    }

    public static function getAvailableCoursesWithStatus() {
        $formfields = array();
        foreach (array('training_course_status','name') as $field) {
            $data = I2CE_FormField::getFormFieldIdAndType('training_course',$field);
            if (!is_array($data)) {
                I2CE::raiseError("Could not available courses b/c could not find field $field in form training_course");
                return array();
            }
            $formfields[] = $data['id'];
        }
        $query = "SELECT le_course_name.record as course_id, le_course_name.string_value AS course , le_status_name.record as status_id, le_status_name.string_value as status ";
        $query.= "FROM last_entry le_course_status ";
        $query.= "JOIN last_entry le_status_name ON le_course_status.integer_value = le_status_name.record ";
        $query.= "JOIN last_entry le_course_name ON le_course_status.record = le_course_name.record ";
        $query.= "WHERE le_course_status.form_field = ? ";
        $query.= "AND le_course_name.form_field = ? ";
        $db = MDB2::singleton();
        $sth = $db->prepare($query,array('integer','integer'), MDB2_PREPARE_RESULT );
        if (I2CE::pearError($sth,"Could not setup statement to get available courses")) {
            return array();
        }
        $results = $sth->execute($formfields);
        if (I2CE::pearError($results,"Could not get available courses")) {
            return array();
        }
        $courses = array();
        while ( $result =& $results->fetchRow() ) {
            $courses[$result->id] = array('name'=>$result->name,'status'=>$result->status,'status_id'=>$result->status_id);
        }
        return $courses;
    }


    public static function getAvailableCourses() {
        $filters = array();
        I2CE::getConfig()->__setIfIsSet($filters,'/modules/training-course/filters/availableCourses',true);
        foreach ($filters as $i=>$val) {
            $val .= ''; //force it to be a string
            if (strlen($val)==0) {
                unset($filters[$i]); //make sure we don't have junk
            }
            $filters[$i] = "'" . mysql_real_escape_string($val) . "'";
        }
        $formfields = array();
        foreach (array('training_course_status','name') as $field) {
            $data = I2CE_FormField::getFormFieldIdAndType('training_course',$field);
            if (!is_array($data)) {
                I2CE::raiseError("Could not available courses b/c could not find field $field in form training_course");
                return array();
            }
            $formfields[] = $data['id'];
        }


        //Gets all course with the specified status
        $query = "SELECT le_course_name.record as id, le_course_name.string_value AS name ";
        $query.= "FROM last_entry le_course_status ";
        $query.= "JOIN last_entry le_status_name ON le_course_status.integer_value = le_status_name.record ";
        $query.= "JOIN last_entry le_course_name ON le_course_status.record = le_course_name.record ";
        $query.= "WHERE le_course_status.form_field = ? ";
        $query.= "AND le_course_name.form_field = ? ";
        if (count($filters) > 0) {
            $query.= "AND le_status_name.string_value in (". implode(',',$filters) .") ";
        }        
        $db = MDB2::singleton();
        $sth = $db->prepare($query,array('integer','integer'), MDB2_PREPARE_RESULT );
        if (I2CE::pearError($sth,"Could not setup statement to get available courses")) {
            return array();
        }
        $results = $sth->execute($formfields);
        if (I2CE::pearError($results,"Could not get available courses")) {
            return array();
        }
        $courses = array();
        while ( $result =& $results->fetchRow() ) {
            $courses[$result->id] = $result->name;
        }
        return $courses;
    }


    public static function lookup($id,$form_name) {
        return self::lookupCourseName($id);
    }

    public static function lookupCourseName($id) {
        $query = "SELECT le_course_name.string_value AS name ";
        $query.= "FROM last_entry le_course_name ";
        $query.= "WHERE le_course_name.form_field = ? ";
        $query.= "AND le_course_name.record = ? LIMIT 1";
        $values = array();
        $data = I2CE_FormField::getFormFieldIdAndType('training_course','name');
        if (!is_array($data)) {
            I2CE::raiseError("Could lookup courses name b/c could not find field name in form training_course");
            return '';
        }
        $values = array( $data['id'], $id);
        $db = MDB2::singleton();
        $sth = $db->prepare($query,array('integer','integer'), MDB2_PREPARE_RESULT );
        if (I2CE::pearError($sth,"Could not setup statement to get available courses")) {
            return array();
        }
        $results = $sth->execute($values);
        if (I2CE::pearError($results,"Could not get available courses")) {
            return array();
        }
        $result = $results->fetchRow() ;
        if ($result) {
            return $result->name;
        } else {
            return '';
        }
    }

    
}

# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
